Decapsulator

Trait Decapsulator 

pub trait Decapsulator {
    type Kem: Kem;

    // Required method
    fn encapsulation_key(&self) -> &<Self::Kem as Kem>::EncapsulationKey;
}
Decapsulator with an associated encapsulation key which can be used for encrypting shared keys that this decapsulator can decrypt.

Required Associated Types

type Kem: Kem

KEM algorithm this decapsulator is for.

Required Methods

fn encapsulation_key(&self) -> &<Self::Kem as Kem>::EncapsulationKey

Encapsulation key which can encrypt ciphertexts this decapsulator can decrypt.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<P> Decapsulator for DecapsulationKey<P>
where P: Kem<EncapsulationKey = EncapsulationKey<P>, SharedKeySize = UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>> + KemParams,

Implementors