pub trait Decapsulator {
type Kem: Kem;
// Required method
fn encapsulation_key(&self) -> &<Self::Kem as Kem>::EncapsulationKey;
}Expand description
Decapsulator with an associated encapsulation key which can be used for encrypting shared keys that this decapsulator can decrypt.
Required Associated Types
Required Methods
Sourcefn encapsulation_key(&self) -> &<Self::Kem as Kem>::EncapsulationKey
fn encapsulation_key(&self) -> &<Self::Kem as Kem>::EncapsulationKey
Encapsulation key which can encrypt ciphertexts this decapsulator can decrypt.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".